@@ -353,3 +353,12 @@ def cli_secret(obj, create_action, grant_action, base_profile):
     Secret(
         obj["project"], obj["config"], create_action, grant_action, base_profile
     ).run()
+
+
+@qa.command(
+    "toggle-maintenance",
+    help="Toggle maintenance mode (requires 'manage:maintenance' permission)",
+)
+@click.pass_obj
+def cli_qa_toggle_maintenance(obj):
+    QA("toggle-maintenance", obj["project"], obj["config"], obj["tokens"]).run()
