@@ -82,33 +82,30 @@ class MergePR:
             )
             logger.info("Card updated")
 
-            with Halo(
-                text="Searching for related QA environments...",
-                spinner="dots",
-                color="magenta",
-            ):
-                response = self._qainit.list(
-                    {
-                        "user": "all",
-                        "card": youtrack_id,
-                        "status": ["created", "updated", "failed", "frozen"],
-                    }
-                ).json()
+            if self._config.user["delete_qa_after_merge"]:
+                with Halo(
+                    text="Searching for related QA environments...",
+                    spinner="dots",
+                    color="magenta",
+                ):
+                    response = self._qainit.list(
+                        {
+                            "user": "all",
+                            "card": youtrack_id,
+                            "status": ["created", "updated", "failed", "frozen"],
+                        }
+                    ).json()
 
-            for qa in response["list"]:
-                logger.info(f"Found {qa['name']}")
+                for qa in response["list"]:
+                    logger.info(f"Found {qa['name']}")
 
-            if (
-                self._config.user["delete_qa_after_merge"]
-                and len(response["list"]) > 0
-                and prompt_utils.ask_confirm(
+                if len(response["list"]) > 0 and prompt_utils.ask_confirm(
                     "Do you want to delete the QA env(s) I found?",
                     default=True,
-                )
-            ):
-                for qa in response["list"]:
-                    logger.info(f"Deleting {qa['name']} ")
-                    self._qainit.delete(qa["hash"])
+                ):
+                    for qa in response["list"]:
+                        logger.info(f"Deleting {qa['name']} ")
+                        self._qainit.delete(qa["hash"])
 
         else:
             logger.warning(
