@@ -4,7 +4,9 @@ import sys
 import json
 import copy
 import re
+import datetime
 
+from dateutil import tz
 from rich.table import Table
 from rich.console import Console
 from suite_py.lib import logger
@@ -55,10 +57,18 @@ class QA:
 
         self._qainit.user_info()
 
-    def _clean_date(self, datetime):
+    def _clean_date(self, datetime_str):
         # expected format: '2021-07-23T14:04:12.000000Z'
-        datetime = datetime.split(".")[0]
-        return datetime.replace("T", " ")
+        datetime_object = datetime.datetime.strptime(
+            datetime_str, "%Y-%m-%dT%H:%M:%S.%fZ"
+        )
+        # Define time zones:
+        utc_time_zone = tz.tzutc()
+        local_time_zone = tz.tzlocal()
+        # Convert time zone
+        utc_datetime_object = datetime_object.replace(tzinfo=utc_time_zone)
+        local_datetime_object = utc_datetime_object.astimezone(local_time_zone)
+        return local_datetime_object.strftime("%d/%m/%Y %H:%M:%S %z")
 
     def _create_instance_table(self):
         instance_table = Table()
