@@ -130,7 +130,7 @@ class Secret:
     def _get_available_secrets(self):
         try:
             secrets = []
-            with open(f"{self._path}/config/secrets.yml") as s:
+            with open(f"{self._path}/config/secrets.yml", encoding="utf-8") as s:
                 yaml_secrets = yaml.load(s, Loader=yaml.FullLoader)
                 secrets = [
                     key for key, values in yaml_secrets.items() if key != "_keys"
